@@ -37,7 +37,11 @@ def logs():
     path = config.default_log_dir
     log_files = []
     for f in os.listdir(path):
-        log_files.append(os.path.join(path, f))
+        item = os.path.join(path, f)
+        if os.path.isfile(item):
+            log_files.append(item)
+    if len(log_files) > 20:
+        log_files = log_files[0:20]
     data = log_files
     data_dict = {api_constants.MGMT_WEBAPP.LOGS_PROPERTY: data}
     response = jsonify(data_dict)
